Module modules

Module modules 

Java 9+ module attribute parser (JVMS 4.7.25).

Extracts the Module attribute from module-info.class files and converts the parsed representation into our ModuleStub model type. This module bridges cafebabe’s ModuleData to our stub types, converting all internal JVM names (/-separated) to fully-qualified names (.-separated).

The Module attribute is only present on module-info.class files produced by javac for Java 9+ module-info.java source files.

Functions

extract_module
Extract module information from a parsed class file.